@@ -119,7 +119,7 @@ class NDiagGHQuadrature(GaussianQuadrature):
         # mean, stddev: [1, b1, b2, ..., bX, dim], usually [1, N, dim]
 
         Z = tf.cast(tf.reshape(self.Z, tf.concat([shape_aux, [self.dim]], axis=0)), mean.dtype)
-        dZ = tf.cast(tf.reshape(self.dZ, tf.concat([shape_aux, [1,]], axis=0)), mean.dtype)
+        dZ = tf.cast(tf.reshape(self.dZ, tf.concat([shape_aux, [1]], axis=0)), mean.dtype)
 
         X = mean + stddev * Z
         W = dZ
