@@ -17,7 +17,7 @@ from typing import Optional
 import tensorflow_probability as tfp
 
 from .. import config
-from .utilities import to_default_float
+from .misc import to_default_float
 
 __all__ = ["positive", "triangular"]
 
