@@ -90,7 +90,8 @@ def test_broadcast_no_active_dims(kernel_class):
 
 
 @pytest.mark.parametrize(
-    "base_class", [kernel for kernel in gpflow.ci_utils.subclasses(kernels.IsotropicStationary)],
+    "base_class",
+    [kernel for kernel in gpflow.ci_utils.subclasses(kernels.IsotropicStationary)],
 )
 def test_broadcast_no_active_dims_periodic(base_class):
     kernel = gpflow.kernels.Periodic(base_class())
