@@ -34,12 +34,14 @@ def build_model(data):
     return model
 
 
-def build_model_with_uniform_prior(data, prior_on, prior_width):
+def build_model_with_uniform_prior_no_transforms(data, prior_on, prior_width):
     def parameter(value):
         low_value = -100
         high_value = low_value + prior_width
         prior = Uniform(low=np.float64(low_value), high=np.float64(high_value))
-        return gpflow.Parameter(value, prior=prior, prior_on=prior_on)
+        return gpflow.Parameter(
+            value, transform=tfp.bijectors.Identity(), prior=prior, prior_on=prior_on
+        )
 
     k = gpflow.kernels.Matern52(lengthscales=0.3)
     k.variance = parameter(k.variance)
@@ -68,8 +70,8 @@ def test_mcmc_helper_parameters():
 
 
 def test_mcmc_helper_target_function_constrained():
-    """ Set up priors on the model parameters such that we can
-    readily compute their expected values. """
+    """Set up priors on the model parameters such that we can
+    readily compute their expected values."""
     config = gpflow.config.Config(positive_bijector="exp")
     with gpflow.config.as_context(config):
         data = build_data()
@@ -115,7 +117,7 @@ def test_mcmc_helper_target_function_unconstrained():
     prior_width = 200.0
 
     data = build_data()
-    model = build_model_with_uniform_prior(data, "unconstrained", prior_width)
+    model = build_model_with_uniform_prior_no_transforms(data, "unconstrained", prior_width)
 
     hmc_helper = gpflow.optimizers.SamplingHelper(
         model.log_posterior_density, model.trainable_parameters
@@ -133,13 +135,12 @@ def test_mcmc_helper_target_function_unconstrained():
 
 @pytest.mark.parametrize("prior_on", ["constrained", "unconstrained"])
 def test_mcmc_helper_target_function_no_transforms(prior_on):
-    """ Verifies the objective for a set of priors where no transforms are set.
-    """
+    """Verifies the objective for a set of priors where no transforms are set."""
     expected_log_prior = 0.0
     prior_width = 200.0
 
     data = build_data()
-    model = build_model_with_uniform_prior(data, prior_on, prior_width)
+    model = build_model_with_uniform_prior_no_transforms(data, prior_on, prior_width)
 
     hmc_helper = gpflow.optimizers.SamplingHelper(
         model.log_posterior_density, model.trainable_parameters
@@ -171,7 +172,9 @@ def test_mcmc_sampler_integration():
     )
 
     hmc = tfp.mcmc.HamiltonianMonteCarlo(
-        target_log_prob_fn=hmc_helper.target_log_prob_fn, num_leapfrog_steps=2, step_size=0.01,
+        target_log_prob_fn=hmc_helper.target_log_prob_fn,
+        num_leapfrog_steps=2,
+        step_size=0.01,
     )
 
     adaptive_hmc = tfp.mcmc.SimpleStepSizeAdaptation(
