@@ -15,6 +15,7 @@
 import numpy as np
 import pytest
 import tensorflow as tf
+from packaging.version import Version
 
 import gpflow
 from gpflow.config import Config, as_context
@@ -100,8 +101,16 @@ def create_model():
 # ------------------------------------------
 
 example_tf_module_variable_dict = {
-    "A.var_trainable": {"value": np.zeros((2, 2, 1)), "trainable": True, "shape": (2, 2, 1),},
-    "A.var_fixed": {"value": np.ones((2, 2, 1)), "trainable": False, "shape": (2, 2, 1),},
+    "A.var_trainable": {
+        "value": np.zeros((2, 2, 1)),
+        "trainable": True,
+        "shape": (2, 2, 1),
+    },
+    "A.var_fixed": {
+        "value": np.ones((2, 2, 1)),
+        "trainable": False,
+        "shape": (2, 2, 1),
+    },
 }
 
 example_module_list_variable_dict = {
@@ -118,7 +127,11 @@ example_module_list_variable_dict = {
 }
 
 kernel_param_dict = {
-    "SquaredExponential.lengthscales": {"value": Data.ls, "trainable": False, "shape": (),},
+    "SquaredExponential.lengthscales": {
+        "value": Data.ls,
+        "trainable": False,
+        "shape": (),
+    },
     "SquaredExponential.variance": {"value": Data.var, "trainable": True, "shape": ()},
 }
 
@@ -137,9 +150,21 @@ model_gp_param_dict = {
     "kernel.lengthscales": kernel_param_dict["SquaredExponential.lengthscales"],
     "kernel.variance": kernel_param_dict["SquaredExponential.variance"],
     "likelihood.variance": {"value": 1.0, "trainable": True, "shape": ()},
-    "inducing_variable.Z": {"value": Data.Z, "trainable": True, "shape": (Data.M, Data.D),},
-    "SVGP.q_mu": {"value": np.zeros((Data.M, 1)), "trainable": False, "shape": (Data.M, 1),},
-    "SVGP.q_sqrt": {"value": np.ones((Data.M, 1)), "trainable": True, "shape": (Data.M, 1),},
+    "inducing_variable.Z": {
+        "value": Data.Z,
+        "trainable": True,
+        "shape": (Data.M, Data.D),
+    },
+    "SVGP.q_mu": {
+        "value": np.zeros((Data.M, 1)),
+        "trainable": False,
+        "shape": (Data.M, 1),
+    },
+    "SVGP.q_sqrt": {
+        "value": np.ones((Data.M, 1)),
+        "trainable": True,
+        "shape": (Data.M, 1),
+    },
 }
 
 example_dag_module_param_dict = {
@@ -147,9 +172,21 @@ example_dag_module_param_dict = {
         "SquaredExponential.lengthscales"
     ],
     "SVGP.likelihood.variance": {"value": 1.0, "trainable": True, "shape": ()},
-    "SVGP.inducing_variable.Z": {"value": Data.Z, "trainable": True, "shape": (Data.M, Data.D),},
-    "SVGP.q_mu": {"value": np.zeros((Data.M, 1)), "trainable": False, "shape": (Data.M, 1),},
-    "SVGP.q_sqrt": {"value": np.ones((Data.M, 1)), "trainable": True, "shape": (Data.M, 1),},
+    "SVGP.inducing_variable.Z": {
+        "value": Data.Z,
+        "trainable": True,
+        "shape": (Data.M, Data.D),
+    },
+    "SVGP.q_mu": {
+        "value": np.zeros((Data.M, 1)),
+        "trainable": False,
+        "shape": (Data.M, 1),
+    },
+    "SVGP.q_sqrt": {
+        "value": np.ones((Data.M, 1)),
+        "trainable": True,
+        "shape": (Data.M, 1),
+    },
 }
 
 compose_kernel_param_print_string = """\
@@ -208,6 +245,32 @@ B.var_fixed                          ResourceVariable                        Fal
 
 # Note: we use grid format here because we have a double reference to the same variable
 # which does not render nicely in the table formatting.
+# The internal structure of the Keras model changed in TensorFlow versions 2.5.0 and 2.6.0.
+example_tf_keras_model_tf_2_6_0 = """\
++-------------------------------+------------------+-------------+---------+-------------+-----------+---------+----------+\n\
+| name                          | class            | transform   | prior   | trainable   | shape     | dtype   | value    |\n\
++===============================+==================+=============+=========+=============+===========+=========+==========+\n\
+| C._trainable_weights[0]       | ResourceVariable |             |         | True        | (2, 2, 1) | float32 | [[[0.... |\n\
+| C.variable                    |                  |             |         |             |           |         |          |\n\
++-------------------------------+------------------+-------------+---------+-------------+-----------+---------+----------+\n\
+| C._trainable_weights[1]       | ResourceVariable |             |         | True        | ()        | float64 | 0.0      |\n\
++-------------------------------+------------------+-------------+---------+-------------+-----------+---------+----------+\n\
+| C._self_tracked_trackables[0] | Parameter        | Identity    |         | True        | ()        | float64 | 0.0      |\n\
+| C.param                       |                  |             |         |             |           |         |          |\n\
++-------------------------------+------------------+-------------+---------+-------------+-----------+---------+----------+"""
+
+
+example_tf_keras_model_tf_2_5_0 = """\
++-------------------------------+------------------+-------------+---------+-------------+-----------+---------+----------+\n\
+| name                          | class            | transform   | prior   | trainable   | shape     | dtype   | value    |\n\
++===============================+==================+=============+=========+=============+===========+=========+==========+\n\
+| C._trainable_weights[0]       | ResourceVariable |             |         | True        | (2, 2, 1) | float32 | [[[0.... |\n\
+| C.variable                    |                  |             |         |             |           |         |          |\n\
++-------------------------------+------------------+-------------+---------+-------------+-----------+---------+----------+\n\
+| C._self_tracked_trackables[0] | Parameter        | Identity    |         | True        | ()        | float64 | 0.0      |\n\
+| C.param                       |                  |             |         |             |           |         |          |\n\
++-------------------------------+------------------+-------------+---------+-------------+-----------+---------+----------+"""
+
 example_tf_keras_model = """\
 +-------------------------+------------------+-------------+---------+-------------+-----------+---------+----------+\n\
 | name                    | class            | transform   | prior   | trainable   | shape     | dtype   | value    |\n\
@@ -218,6 +281,11 @@ example_tf_keras_model = """\
 | C.param                 | Parameter        | Identity    |         | True        | ()        | float64 | 0.0      |\n\
 +-------------------------+------------------+-------------+---------+-------------+-----------+---------+----------+"""
 
+if Version(tf.__version__) >= Version("2.6"):
+    example_tf_keras_model = example_tf_keras_model_tf_2_6_0
+elif Version(tf.__version__) >= Version("2.5"):
+    example_tf_keras_model = example_tf_keras_model_tf_2_5_0
+
 # ------------------------------------------
 # Fixtures
 # ------------------------------------------
@@ -260,7 +328,10 @@ def test_leaf_components_registers_variable_properties(module_callable, expected
 
 
 @pytest.mark.parametrize(
-    "module_callable, expected_param_dicts", [(create_compose_kernel, compose_kernel_param_dict),],
+    "module_callable, expected_param_dicts",
+    [
+        (create_compose_kernel, compose_kernel_param_dict),
+    ],
 )
 def test_leaf_components_registers_compose_kernel_variable_properties(
     module_callable, expected_param_dicts
@@ -279,7 +350,10 @@ def test_leaf_components_registers_compose_kernel_variable_properties(
 
 @pytest.mark.parametrize(
     "module_class, expected_var_dicts",
-    [(A, example_tf_module_variable_dict), (B, example_module_list_variable_dict),],
+    [
+        (A, example_tf_module_variable_dict),
+        (B, example_module_list_variable_dict),
+    ],
 )
 def test_leaf_components_registers_param_properties(module_class, expected_var_dicts):
     module = module_class()
