@@ -52,7 +52,10 @@ def test_svgp(whiten, q_diag):
 
     # test with explicitly unknown shapes:
     tensor_spec = tf.TensorSpec(shape=None, dtype=default_float())
-    elbo = tf.function(model.elbo, input_signature=[(tensor_spec, tensor_spec)],)
+    elbo = tf.function(
+        model.elbo,
+        input_signature=[(tensor_spec, tensor_spec)],
+    )
 
     @tf.function
     def model_closure():
@@ -62,7 +65,10 @@ def test_svgp(whiten, q_diag):
 
     # simply test whether it runs without erroring...:
     opt.minimize(
-        model_closure, variables=model.trainable_variables, options=dict(maxiter=3), compile=True,
+        model_closure,
+        variables=model.trainable_variables,
+        options=dict(maxiter=3),
+        compile=True,
     )
 
 
@@ -78,7 +84,10 @@ def test_multiclass():
 
     # test with explicitly unknown shapes:
     tensor_spec = tf.TensorSpec(shape=None, dtype=default_float())
-    elbo = tf.function(model.elbo, input_signature=[(tensor_spec, tensor_spec)],)
+    elbo = tf.function(
+        model.elbo,
+        input_signature=[(tensor_spec, tensor_spec)],
+    )
 
     @tf.function
     def model_closure():
@@ -88,5 +97,8 @@ def test_multiclass():
 
     # simply test whether it runs without erroring...:
     opt.minimize(
-        model_closure, variables=model.trainable_variables, options=dict(maxiter=3), compile=True,
+        model_closure,
+        variables=model.trainable_variables,
+        options=dict(maxiter=3),
+        compile=True,
     )
